package hsmw.jotto5.beleg.data;

import java.lang.annotation.*;

/**
 * Basisklasse für ein beliebiges DataObject.
 *
 * Alle spezifischen Objekte (im Sinne dieser Anwendung) erben von dieser Klasse.
 * <p>
 * Das DataObject und alle Kindklassen sind für Klassen außerhalb des Data-Pakets vollständig mutable,
 * um das Bearbeiten über das Webinterface zu erlauben.
 */
public abstract class DataObject {

	/**
	 * Annotation um über das Webinterface abrufbare Felder zu kennzeichnen.
	 */
	@Retention(RetentionPolicy.RUNTIME)
	@Target(ElementType.FIELD)
	public @interface WebField {
		public String displayAs() default "";
	}

	@WebField(displayAs = "Anzeigename")
	public final String displayName;

	// Wird absichtlich nicht angezeigt, als Demonstration
	public final String uid;

	/**
	 * Konstruktor für manuelles Erzeugen.
	 *
	 * Wird nur von Kindklassen verwendet. Dient dazu, ein temporäres
	 * DataObject ohne Model-Bindung zu erzeugen.
	 * @param displayName Der Anzeigename des Objektes 
	 */ 
	protected DataObject(String uid, String displayName) {
		this.uid = uid;
		this.displayName = displayName;
	}

}
